@@ -1,4 +1,4 @@
-__version__ = '1.11'
+__version__ = '1.11.2'
 
 
 def setup(app):
@@ -6,3 +6,9 @@ def setup(app):
     app.add_config_value('doxylink', {}, 'env')
     app.add_config_value('doxylink_pdf_files', {}, 'env')
     app.connect('builder-inited', setup_doxylink_roles)
+
+    return {
+        "version": __version__,
+        "parallel_read_safe": True,
+        "parallel_write_safe": True,
+    }
